@@ -45,6 +45,25 @@ const (
 	defaultDirName = ".tenv"
 )
 
+const (
+	SignValidation ValidationMode = iota
+	ShaValidation
+	NoValidation
+)
+
+type ValidationMode uint8
+
+func ParseValidationMode(mode string) ValidationMode {
+	switch mode {
+	case "none":
+		return NoValidation
+	case "sha":
+		return ShaValidation
+	default:
+		return SignValidation
+	}
+}
+
 type Config struct {
 	Arch             string
 	Atmos            RemoteConfig
@@ -55,11 +74,11 @@ type Config struct {
 	Getenv           configutils.GetenvFunc
 	GithubActions    bool
 	GithubToken      string
+	LockPath         string
 	remoteConfLoaded bool
 	RemoteConfPath   string
 	RootPath         string
 	SkipInstall      bool
-	SkipSignature    bool
 	Tf               RemoteConfig
 	TfKeyPathOrURL   string
 	Tg               RemoteConfig
@@ -67,6 +86,7 @@ type Config struct {
 	Tofu             RemoteConfig
 	TofuKeyPathOrURL string
 	UserPath         string
+	Validation       ValidationMode
 	WorkPath         string
 }
 
@@ -76,12 +96,15 @@ func DefaultConfig() (Config, error) {
 		return Config{}, err
 	}
 
+	tenvPath := filepath.Join(userPath, defaultDirName)
+
 	return Config{
 		Arch:             runtime.GOARCH,
 		Atmos:            makeDefaultRemoteConfig(atmosurl.Github, githuburl.Base),
 		Getenv:           EmptyGetenv,
+		LockPath:         tenvPath,
 		remoteConfLoaded: true,
-		RootPath:         filepath.Join(userPath, defaultDirName),
+		RootPath:         tenvPath,
 		SkipInstall:      true,
 		Tf:               makeDefaultRemoteConfig(terraformurl.Hashicorp, terraformurl.Hashicorp),
 		Tg:               makeDefaultRemoteConfig(terragrunturl.Github, githuburl.Base),
@@ -89,6 +112,7 @@ func DefaultConfig() (Config, error) {
 		Tofu:             makeDefaultRemoteConfig(tofuurl.Github, githuburl.Base),
 		UserPath:         userPath,
 		WorkPath:         ".",
+		Validation:       SignValidation,
 		TfKeyPathOrURL:   terraformurl.PublicKey,
 		TofuKeyPathOrURL: tofuurl.PublicKey,
 	}, nil
@@ -122,6 +146,11 @@ func InitConfigFromEnv() (Config, error) {
 		rootPath = filepath.Join(userPath, defaultDirName)
 	}
 
+	lockPath := getenv(envname.TenvLockPath)
+	if lockPath == "" {
+		lockPath = rootPath // Default to root path for backward compatibility
+	}
+
 	quiet, err := getenv.Bool(false, envname.TenvQuiet)
 	if err != nil {
 		return Config{}, err
@@ -135,6 +164,7 @@ func InitConfigFromEnv() (Config, error) {
 		Getenv:           getenv,
 		GithubActions:    getenv.Present(envname.GithubActions),
 		GithubToken:      getenv.Fallback(envname.TenvToken, envname.TofuToken),
+		LockPath:         lockPath,
 		RemoteConfPath:   getenv(envname.TenvRemoteConf),
 		RootPath:         rootPath,
 		SkipInstall:      !autoInstall,
@@ -145,6 +175,7 @@ func InitConfigFromEnv() (Config, error) {
 		Tofu:             makeRemoteConfig(getenv, envname.TofuRemoteURL, envname.TofuListURL, envname.TofuInstallMode, envname.TofuListMode, tofuurl.Github, githuburl.Base),
 		TofuKeyPathOrURL: getenv.WithDefault(tofuurl.PublicKey, envname.TofuOpenTofuPGPKey),
 		UserPath:         userPath,
+		Validation:       ParseValidationMode(getenv(envname.TenvValidation)),
 		WorkPath:         ".",
 	}, nil
 }
@@ -174,6 +205,15 @@ func (conf *Config) InitDisplayer(proxyCall bool) {
 	}
 }
 
+func (conf *Config) InitValidation(skipSum bool, skipSign bool) {
+	switch {
+	case skipSum: // higher priority to --skip-sha
+		conf.Validation = NoValidation
+	case skipSign && conf.Validation != NoValidation:
+		conf.Validation = ShaValidation
+	}
+}
+
 func (conf *Config) InitInstall(forceInstall bool, forceNoInstall bool) {
 	switch {
 	case forceNoInstall: // higher priority to --no-install
